**2.0.8 - 02/15/22**

 - Autoformat code with black and isort.
 - Add black and isort checks to CI.

**2.0.7 - 02/12/22**

 - Modernize CI.
 - Add PR template.
 - Update to BSD 3-clause license.
 - Squash warnings in doc building
 - Fix remote doc builds.

**2.0.6 - 08/31/21**

 - Add credentials to repository 
 
**2.0.5 - 08/31/21**

 - Set python deployment version to 3.8 
 
**2.0.4 - 08/31/21**

 - Implement quantile (ppf) function for EnsembleDistribution using 2 pr
 - CI changes
 - Update authors and maintainers

**2.0.3 - 09/08/20**

 - Correction to the Beta distribution wrapper.
 - supress RuntimeWarning around dist calculation
 - Update authors and maintainers

**2.0.2 - 11/18/19**

 - Fix set logic in data frame formatting.

**2.0.1 - 03/12/19**

 - Add API documentation.
 - Add cdf to all distributions.
 - Bugfix to handle case where computable is empty for ppf, pdf, and cdf.

**2.0.0 - 02/13/19**

 - Full rewrite of risk distributions.
 - Separation of input data handling from parameter calculation.
 - Improved interactive usability.

**1.0.1 - 11/07/18**

 - Clean up separated distributions.
 - Allow for only mean and standard deviation or pre-calculated parameters.

**1.0.0 - 10/29/18**

 - Initial Release

